import Security
from PyObjCTools.TestSupport import TestCase


class Testoidsattr(TestCase):
    def test_unsuppported(self):
        self.assertFalse(hasattr(Security, "CSSMOID_ObjectClass"))
        self.assertFalse(hasattr(Security, "CSSMOID_AliasedEntryName"))
        self.assertFalse(hasattr(Security, "CSSMOID_KnowledgeInformation"))
        self.assertFalse(hasattr(Security, "CSSMOID_CommonName"))
        self.assertFalse(hasattr(Security, "CSSMOID_Surname"))
        self.assertFalse(hasattr(Security, "CSSMOID_SerialNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_CountryName"))
        self.assertFalse(hasattr(Security, "CSSMOID_LocalityName"))
        self.assertFalse(hasattr(Security, "CSSMOID_StateProvinceName"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveStateProvinceName"))
        self.assertFalse(hasattr(Security, "CSSMOID_StreetAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveStreetAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_OrganizationName"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveOrganizationName"))
        self.assertFalse(hasattr(Security, "CSSMOID_OrganizationalUnitName"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveOrganizationalUnitName"))
        self.assertFalse(hasattr(Security, "CSSMOID_Title"))
        self.assertFalse(hasattr(Security, "CSSMOID_Description"))
        self.assertFalse(hasattr(Security, "CSSMOID_SearchGuide"))
        self.assertFalse(hasattr(Security, "CSSMOID_BusinessCategory"))
        self.assertFalse(hasattr(Security, "CSSMOID_PostalAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectivePostalAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_PostalCode"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectivePostalCode"))
        self.assertFalse(hasattr(Security, "CSSMOID_PostOfficeBox"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectivePostOfficeBox"))
        self.assertFalse(hasattr(Security, "CSSMOID_PhysicalDeliveryOfficeName"))
        self.assertFalse(
            hasattr(Security, "CSSMOID_CollectivePhysicalDeliveryOfficeName")
        )
        self.assertFalse(hasattr(Security, "CSSMOID_TelephoneNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveTelephoneNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_TelexNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveTelexNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_TelexTerminalIdentifier"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveTelexTerminalIdentifier"))
        self.assertFalse(hasattr(Security, "CSSMOID_FacsimileTelephoneNumber"))
        self.assertFalse(
            hasattr(Security, "CSSMOID_CollectiveFacsimileTelephoneNumber")
        )
        self.assertFalse(hasattr(Security, "CSSMOID_X_121Address"))
        self.assertFalse(hasattr(Security, "CSSMOID_InternationalISDNNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_CollectiveInternationalISDNNumber"))
        self.assertFalse(hasattr(Security, "CSSMOID_RegisteredAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_DestinationIndicator"))
        self.assertFalse(hasattr(Security, "CSSMOID_PreferredDeliveryMethod"))
        self.assertFalse(hasattr(Security, "CSSMOID_PresentationAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_SupportedApplicationContext"))
        self.assertFalse(hasattr(Security, "CSSMOID_Member"))
        self.assertFalse(hasattr(Security, "CSSMOID_Owner"))
        self.assertFalse(hasattr(Security, "CSSMOID_RoleOccupant"))
        self.assertFalse(hasattr(Security, "CSSMOID_SeeAlso"))
        self.assertFalse(hasattr(Security, "CSSMOID_UserPassword"))
        self.assertFalse(hasattr(Security, "CSSMOID_UserCertificate"))
        self.assertFalse(hasattr(Security, "CSSMOID_CACertificate"))
        self.assertFalse(hasattr(Security, "CSSMOID_AuthorityRevocationList"))
        self.assertFalse(hasattr(Security, "CSSMOID_CertificateRevocationList"))
        self.assertFalse(hasattr(Security, "CSSMOID_CrossCertificatePair"))
        self.assertFalse(hasattr(Security, "CSSMOID_Name"))
        self.assertFalse(hasattr(Security, "CSSMOID_GivenName"))
        self.assertFalse(hasattr(Security, "CSSMOID_Initials"))
        self.assertFalse(hasattr(Security, "CSSMOID_GenerationQualifier"))
        self.assertFalse(hasattr(Security, "CSSMOID_UniqueIdentifier"))
        self.assertFalse(hasattr(Security, "CSSMOID_DNQualifier"))
        self.assertFalse(hasattr(Security, "CSSMOID_EnhancedSearchGuide"))
        self.assertFalse(hasattr(Security, "CSSMOID_ProtocolInformation"))
        self.assertFalse(hasattr(Security, "CSSMOID_DistinguishedName"))
        self.assertFalse(hasattr(Security, "CSSMOID_UniqueMember"))
        self.assertFalse(hasattr(Security, "CSSMOID_HouseIdentifier"))
        self.assertFalse(hasattr(Security, "CSSMOID_EmailAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_UnstructuredName"))
        self.assertFalse(hasattr(Security, "CSSMOID_ContentType"))
        self.assertFalse(hasattr(Security, "CSSMOID_MessageDigest"))
        self.assertFalse(hasattr(Security, "CSSMOID_SigningTime"))
        self.assertFalse(hasattr(Security, "CSSMOID_CounterSignature"))
        self.assertFalse(hasattr(Security, "CSSMOID_ChallengePassword"))
        self.assertFalse(hasattr(Security, "CSSMOID_UnstructuredAddress"))
        self.assertFalse(hasattr(Security, "CSSMOID_ExtendedCertificateAttributes"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_Id_Ct_TSTInfo"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_TimeStampToken"))
        self.assertFalse(hasattr(Security, "CSSMOID_QT_CPS"))
        self.assertFalse(hasattr(Security, "CSSMOID_QT_UNOTICE"))
        self.assertFalse(hasattr(Security, "CSSMOID_AD_OCSP"))
        self.assertFalse(hasattr(Security, "CSSMOID_AD_CA_ISSUERS"))
        self.assertFalse(hasattr(Security, "CSSMOID_AD_TIME_STAMPING"))
        self.assertFalse(hasattr(Security, "CSSMOID_AD_CA_REPOSITORY"))
        self.assertFalse(hasattr(Security, "CSSMOID_PDA_DATE_OF_BIRTH"))
        self.assertFalse(hasattr(Security, "CSSMOID_PDA_PLACE_OF_BIRTH"))
        self.assertFalse(hasattr(Security, "CSSMOID_PDA_GENDER"))
        self.assertFalse(hasattr(Security, "CSSMOID_PDA_COUNTRY_CITIZEN"))
        self.assertFalse(hasattr(Security, "CSSMOID_PDA_COUNTRY_RESIDENCE"))
        self.assertFalse(hasattr(Security, "CSSMOID_OID_QCS_SYNTAX_V1"))
        self.assertFalse(hasattr(Security, "CSSMOID_OID_QCS_SYNTAX_V2"))
        self.assertFalse(hasattr(Security, "CSSMOID_ETSI_QCS_QC_COMPLIANCE"))
        self.assertFalse(hasattr(Security, "CSSMOID_ETSI_QCS_QC_LIMIT_VALUE"))
        self.assertFalse(hasattr(Security, "CSSMOID_ETSI_QCS_QC_RETENTION"))
        self.assertFalse(hasattr(Security, "CSSMOID_ETSI_QCS_QC_SSCD"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_Data"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_SignedData"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_EnvelopedData"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_SignedAndEnvelopedData"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_DigestedData"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_EncryptedData"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_DataWithAttributes"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS7_EncryptedPrivateKeyInfo"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_FriendlyName"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_LocalKeyId"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_CertTypes"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_CrlTypes"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_X509Certificate"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_SdsiCertificate"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS9_X509Crl"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS12_keyBag"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS12_shroudedKeyBag"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS12_certBag"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS12_crlBag"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS12_secretBag"))
        self.assertFalse(hasattr(Security, "CSSMOID_PKCS12_safeContentsBag"))
        self.assertFalse(hasattr(Security, "CSSMOID_UserID"))
        self.assertFalse(hasattr(Security, "CSSMOID_DomainComponent"))
        self.assertFalse(hasattr(Security, "CSSMOID_KERBv5_PKINIT_AUTH_DATA"))
        self.assertFalse(hasattr(Security, "CSSMOID_KERBv5_PKINIT_DH_KEY_DATA"))
        self.assertFalse(hasattr(Security, "CSSMOID_KERBv5_PKINIT_RKEY_DATA"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62_FieldType"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62_PubKeyType"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62_EllCurve"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62_C_TwoCurve"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62_PrimeCurve"))
        self.assertFalse(hasattr(Security, "CSSMOID_X9_62_SigType"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp192r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp256r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_Certicom"))
        self.assertFalse(hasattr(Security, "CSSMOID_CerticomEllCurve"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp112r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp112r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp128r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp128r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp160k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp160r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp160r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp192k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp224k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp224r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp256k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp384r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_secp521r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect113r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect113r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect131r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect131r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect163k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect163r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect163r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect193r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect193r2"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect233k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect233r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect239k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect283k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect283r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect409k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect409r1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect571k1"))
        self.assertFalse(hasattr(Security, "CSSMOID_sect571r1"))
